@@ -1,7 +1,5 @@
 import ujson
 
-from google.protobuf.pyext._message import RepeatedCompositeContainer
-
 from ..client.exceptions import ParamError
 
 from .check import check_pass_param
@@ -149,14 +147,18 @@ class TopKQueryResult:
         if len(id_list) != len(dis_list):
             raise ParamError("number of id not match distance ")
 
-        col = len(id_list) // self._nq if self._nq > 0 else 0
+        len_ = len(id_list)
+        col = len_ // self._nq if self._nq > 0 else 0
 
         if col == 0:
             return
 
-        for si, i in enumerate(range(0, len(id_list), col)):
-            k = i + col
-            for j in range(i, i + col):
+        if len_ % col != 0:
+            raise ValueError("Search result is not aligned. (row_num={}, len of ids={})".format(_raw.row_num, len_))
+
+        for si, i in enumerate(range(0, len_, col)):
+            k = min(i + col, len_)
+            for j in range(i, k):
                 if id_list[j] == -1:
                     k = j
                     break
@@ -344,7 +346,8 @@ class HybridEntityResult:
         if index < len(self._entity):
             return self._entity[index]
         if index == len(self._entity):
-            return list(self._vector.float_data) if len(self._vector.float_data) > 0 else bytes(self._vector.binary_data)
+            return list(self._vector.float_data) if len(self._vector.float_data) > 0 else bytes(
+                self._vector.binary_data)
 
         raise ValueError("Out of range ... ")
 
@@ -388,7 +391,8 @@ class HybridRawResult(LoopBase):
 
         item_entities = [e[item] for e in self._entities]
 
-        return HybridEntityResult(self._field_names, self._ids[item], item_entities, self._vectors[item], self._distances[item])
+        return HybridEntityResult(self._field_names, self._ids[item], item_entities, self._vectors[item],
+                                  self._distances[item])
         # if item in self._field_names:
         #     index = self._field_names[item]
 
@@ -419,7 +423,8 @@ class HybridResult(LoopBase):
 
         entities = self._raw.entity
 
-        slice_entity = lambda e, start, end: e.int_value[start: end] if len(e.int_value) > 0 else e.double_value[start: end]
+        slice_entity = lambda e, start, end: e.int_value[start: end] if len(e.int_value) > 0 else e.double_value[
+                                                                                                  start: end]
         seg_ids = self._raw.entity.entity_id[seg_start: seg_end]
         seg_entities = [slice_entity(e, seg_start, seg_end) for e in entities.attr_data]
         seg_vectors = self._raw.entity.vector_data[0].value[seg_start: seg_end]
@@ -479,6 +484,7 @@ class HEntitySet(LoopBase):
     def field_names(self):
         return list(self._raw.field_names)
 
+
 class IndexParam:
     """
     Index Param
@@ -510,10 +516,10 @@ class IndexParam:
         self._collection_name = collection_name
         self._index_type = index_type
 
-        if isinstance(params, RepeatedCompositeContainer):
-            self._params = ujson.loads(params[0].value)
-        else:
-            self._params = params
+        # if isinstance(params, RepeatedCompositeContainer):
+        #     self._params = ujson.loads(params[0].value)
+        # else:
+        self._params = ujson.loads(params)
 
     def __str__(self):
         attr_list = ['%s=%r' % (key.lstrip('_'), value)
