@@ -41,17 +41,17 @@ def error_handler(*rargs):
                 return func(self, *args, **kwargs)
             except grpc.FutureTimeoutError as e:
                 record_dict["RPC timeout"] = str(datetime.datetime.now())
-                LOGGER.error("\n{}\nRequest timeout: {}\n\t{}".format(func.__name__, e, record_dict))
+                LOGGER.error("\nAddr [{}] {}\nRequest timeout: {}\n\t{}".format(self.server_address, func.__name__, e, record_dict))
                 status = Status(Status.UNEXPECTED_ERROR, message='Request timeout')
                 return status if not rargs else tuple([status]) + rargs
             except grpc.RpcError as e:
                 record_dict["RPC error"] = str(datetime.datetime.now())
-                LOGGER.error("\n{}\nRpc error: {}\n\t{}".format(func.__name__, e, record_dict))
+                LOGGER.error("\nAddr [{}] {}\nRpc error: {}\n\t{}".format(self.server_address, func.__name__, e, record_dict))
                 status = Status(e.code(), message='Error occurred. {}'.format(e.details()))
                 return status if not rargs else tuple([status]) + rargs
             except Exception as e:
                 record_dict["Exception"] = str(datetime.datetime.now())
-                LOGGER.error("{}\nExcepted error: {}\n\t{}".format(func.__name__, e, record_dict))
+                LOGGER.error("\nAddr [{}] {}\nExcepted error: {}\n\t{}".format(self.server_address, func.__name__, e, record_dict))
                 raise e
 
         return handler
@@ -155,7 +155,8 @@ class GrpcHandler(ConnectIntf):
             self._uri,
             options=[(cygrpc.ChannelArgKey.max_send_message_length, -1),
                      (cygrpc.ChannelArgKey.max_receive_message_length, -1),
-                     (b'grpc.enable_retries', 1)]
+                     ('grpc.enable_retries', 1),
+                     ('grpc.keepalive_time_ms', 55000)]
                      # (b'grpc.enable_http_proxy', 0)]
         )
         self._stub = milvus_pb2_grpc.MilvusServiceStub(self._channel)
@@ -259,9 +260,7 @@ class GrpcHandler(ConnectIntf):
     def _cmd(self, cmd, timeout=30):
         cmd = Prepare.cmd(cmd)
         rf = self._stub.Cmd.future(cmd, wait_for_ready=True, timeout=timeout)
-        # rf = self._stub.Cmd.future(cmd, metadata=(('request_id', str(self._get_request_id())),), wait_for_ready=True, timeout=timeout)
         response = rf.result()
-        rf.__del__()
         if response.status.error_code == 0:
             return Status(message='Success!'), response.string_reply
 
@@ -294,7 +293,6 @@ class GrpcHandler(ConnectIntf):
 
         rf = self._stub.CreateCollection.future(collection_schema, wait_for_ready=True, timeout=timeout)
         status = rf.result()
-        rf.__del__()
         if status.error_code == 0:
             return Status(message='Create collection successfully!')
 
@@ -331,7 +329,6 @@ class GrpcHandler(ConnectIntf):
 
         rf = self._stub.HasCollection.future(collection_name, wait_for_ready=True, timeout=timeout)
         reply = rf.result()
-        rf.__del__()
         if reply.status.error_code == 0:
             return Status(), reply.bool_reply
 
@@ -353,7 +350,6 @@ class GrpcHandler(ConnectIntf):
         collection_name = Prepare.collection_name(collection_name)
         rf = self._stub.DescribeCollection.future(collection_name, wait_for_ready=True, timeout=timeout)
         response = rf.result()
-        rf.__del__()
 
         if response.status.error_code == 0:
             collection = CollectionSchema(
@@ -385,7 +381,6 @@ class GrpcHandler(ConnectIntf):
 
         rf = self._stub.CountCollection.future(collection_name, wait_for_ready=True, timeout=timeout)
         response = rf.result()
-        rf.__del__()
         if response.status.error_code == 0:
             return Status(message='Success!'), response.collection_row_count
 
@@ -408,7 +403,6 @@ class GrpcHandler(ConnectIntf):
         cmd = Prepare.cmd('show_collections')
         rf = self._stub.ShowCollections.future(cmd, wait_for_ready=True, timeout=timeout)
         response = rf.result()
-        rf.__del__()
         if response.status.error_code == 0:
             return Status(message='Show collections successfully!'), \
                    [name for name in response.collection_names if len(name) > 0]
@@ -420,7 +414,6 @@ class GrpcHandler(ConnectIntf):
 
         rf = self._stub.ShowCollectionInfo.future(request, wait_for_ready=True, timeout=timeout)
         response = rf.result()
-        rf.__del__()
         rpc_status = response.status
 
         if rpc_status.error_code == 0:
@@ -430,7 +423,7 @@ class GrpcHandler(ConnectIntf):
         return Status(rpc_status.error_code, rpc_status.reason), None
 
     @error_handler()
-    def preload_collection(self, collection_name, timeout=None):
+    def preload_collection(self, collection_name, partition_tags=None, timeout=None):
         """
         Load collection to cache in advance
 
@@ -441,8 +434,8 @@ class GrpcHandler(ConnectIntf):
             Status:  indicate if invoke is successful
         """
 
-        collection_name = Prepare.collection_name(collection_name)
-        status = self._stub.PreloadCollection.future(collection_name, wait_for_ready=True, timeout=timeout).result()
+        param = Prepare.preload_param(collection_name, partition_tags)
+        status = self._stub.PreloadCollection.future(param, wait_for_ready=True, timeout=timeout).result()
         return Status(code=status.error_code, message=status.reason)
 
     @error_handler()
@@ -468,7 +461,6 @@ class GrpcHandler(ConnectIntf):
 
         rf = self._stub.DropCollection.future(collection_name, wait_for_ready=True, timeout=timeout)
         status = rf.result()
-        rf.__del__()
         if status.error_code == 0:
             return Status(message='Delete collection successfully!')
         return Status(code=status.error_code, message=status.reason)
@@ -521,7 +513,6 @@ class GrpcHandler(ConnectIntf):
             return InsertFuture(rf, cb)
 
         response = rf.result()
-        rf.__del__()
         if response.status.error_code == 0:
             return Status(message='Add vectors successfully!'), list(response.vector_id_array)
 
@@ -542,7 +533,6 @@ class GrpcHandler(ConnectIntf):
 
         rf = self._stub.GetVectorsByID.future(request, wait_for_ready=True, timeout=timeout)
         response = rf.result()
-        rf.__del__()
         status = response.status
         if status.error_code == 0:
             status = Status(message="Obtain vector successfully")
@@ -569,7 +559,6 @@ class GrpcHandler(ConnectIntf):
 
         rf = self._stub.GetVectorIDs.future(request, wait_for_ready=True, timeout=timeout)
         response = rf.result()
-        rf.__del__()
 
         if response.status.error_code == 0:
             return Status(), list(response.vector_id_array)
@@ -606,7 +595,6 @@ class GrpcHandler(ConnectIntf):
             cb = kwargs.get("_callback", None)
             return CreateIndexFuture(future, cb)
         status = future.result()
-        future.__del__()
 
         if status.error_code == 0:
             return Status(message='Build index successfully!')
@@ -630,7 +618,6 @@ class GrpcHandler(ConnectIntf):
 
         rf = self._stub.DescribeIndex.future(collection_name, wait_for_ready=True, timeout=timeout)
         index_param = rf.result()
-        rf.__del__()
 
         status = index_param.status
 
@@ -638,7 +625,7 @@ class GrpcHandler(ConnectIntf):
             return Status(message="Successfully"), \
                    IndexParam(index_param.collection_name,
                               index_param.index_type,
-                              index_param.extra_params)
+                              index_param.extra_params[0].value)
 
         return Status(code=status.error_code, message=status.reason), None
 
@@ -659,7 +646,6 @@ class GrpcHandler(ConnectIntf):
         collection_name = Prepare.collection_name(collection_name)
         rf = self._stub.DropIndex.future(collection_name, wait_for_ready=True, timeout=timeout)
         status = rf.result()
-        rf.__del__()
         # status = self._stub.DropIndex.future(collection_name).result(timeout=timeout)
         return Status(code=status.error_code, message=status.reason)
 
@@ -689,7 +675,6 @@ class GrpcHandler(ConnectIntf):
         request = Prepare.partition_param(collection_name, partition_tag)
         rf = self._stub.CreatePartition.future(request, wait_for_ready=True, timeout=timeout)
         response = rf.result()
-        rf.__del__()
         return Status(code=response.error_code, message=response.reason)
 
     @error_handler(False)
@@ -697,7 +682,6 @@ class GrpcHandler(ConnectIntf):
         request = Prepare.partition_param(collection_name, partition_tag)
         rf = self._stub.HasPartition.future(request, wait_for_ready=True, timeout=timeout)
         response = rf.result()
-        rf.__del__()
         status = response.status
         return Status(code=status.error_code, message=status.reason), response.bool_reply
 
@@ -721,7 +705,6 @@ class GrpcHandler(ConnectIntf):
 
         rf = self._stub.ShowPartitions.future(request, wait_for_ready=True, timeout=timeout)
         response = rf.result()
-        rf.__del__()
         # response = self._stub.ShowPartitions.future(request).result(timeout=timeout)
         status = response.status
         if status.error_code == 0:
@@ -752,7 +735,6 @@ class GrpcHandler(ConnectIntf):
 
         rf = self._stub.DropPartition.future(request, wait_for_ready=True, timeout=timeout)
         response = rf.result()
-        rf.__del__()
         # response = self._stub.DropPartition.future(request).result(timeout=timeout)
         return Status(code=response.error_code, message=response.reason)
 
@@ -768,7 +750,6 @@ class GrpcHandler(ConnectIntf):
             return SearchFuture(future, func)
         ft = self._stub.Search.future(request)
         response = ft.result()
-        ft.__del__()
         self._search_hook.aft_search()
 
         if self._search_hook.on_response():
@@ -816,7 +797,6 @@ class GrpcHandler(ConnectIntf):
 
         ft = self._stub.SearchByID.future(request, wait_for_ready=True, timeout=timeout)
         response = ft.result()
-        ft.__del__()
         self._search_hook.aft_search()
 
         if self._search_hook.on_response():
@@ -878,7 +858,6 @@ class GrpcHandler(ConnectIntf):
 
         ft = self._stub.SearchInFiles.future(infos, wait_for_ready=True, timeout=timeout)
         response = ft.result()
-        ft.__del__()
         self._search_file_hook.aft_search()
 
         if self._search_file_hook.on_response():
@@ -897,7 +876,6 @@ class GrpcHandler(ConnectIntf):
 
         rf = self._stub.DeleteByID.future(request, wait_for_ready=True, timeout=timeout)
         status = rf.result()
-        rf.__del__()
         # status = self._stub.DeleteByID.future(request).result(timeout=timeout)
         return Status(code=status.error_code, message=status.reason)
 
@@ -909,7 +887,6 @@ class GrpcHandler(ConnectIntf):
             cb = kwargs.get("_callback", None)
             return FlushFuture(future, cb)
         response = future.result()
-        future.__del__()
         return Status(code=response.error_code, message=response.reason)
 
     @error_handler()
@@ -920,7 +897,6 @@ class GrpcHandler(ConnectIntf):
             cb = kwargs.get("_callback", None)
             return CompactFuture(future, cb)
         response = future.result()
-        future.__del__()
         return Status(code=response.error_code, message=response.reason)
 
     def set_config(self, parent_key, child_key, value):
